@@ -25,6 +25,12 @@ rm -rf docs/_build/html/javadoc
 
 # remove stale tutorials and always build from scratch.
 rm -rf docs/tutorials
+rm -rf docs/vta/tutorials
+
+# cleanup stale log files
+find . -type f -path "*.log" | xargs rm -f
+find . -type f -path "*.pyc" | xargs rm -f
+make cython3
 
 # C++ doc
 make doc
@@ -37,7 +43,6 @@ mv out docs/_build/html/jsdoc
 make javadoc
 mv jvm/core/target/site/apidocs docs/_build/html/javadoc
 
-rm -rf python/tvm/*.pyc python/tvm/*/*.pyc python/tvm/*/*/*.pyc
 
 cd docs
 PYTHONPATH=`pwd`/../python make html
